package de.fhw.komponentenarchitekturen.knauf.jsf;


/**This is the only Managed Bean of my sample: it requires
 * three input parameters "a", "b" and "c" and has a handler method @see calculate ,
 * which computes cuboid volume and surface.
 * The result can be queried with the corresponding properties.
 * 
 * The handler stores a history of all side length inputs, which
 * are stored in session.
 */
public class GeometricModelHandler
{
  /**Current user input: side length a */
  private double dblA = 0;
  /**Current user input: side length b */
  private double dblB = 0;
  /**Current user input: side length c */
  private double dblC = 0;
  
  /**Calculated Surface - is calculated in the handler method @see calculate */
  private double dblSurface = 0;
  /**Calculated Volume - is calculated in the handler method @see calculate */
  private double dblVolume = 0;
  
  /**This is the history of all calculations in the current session. */
  private History history = new History();
  
  /**Get current user input for side length a
   * @return Side length a (might be default value if no input is available) 
   */
  public double getA()
  {
    return dblA;
  }

  /**Set side length a. This method is called only by the JSF framework
   * in this sample
   * @param dblA Side length a
   */
  public void setA(double dblA)
  {
    this.dblA = dblA;
  }

  /**Get current user input for side length b
   * @return Side length b (might be default value if no input is available)
   */
  public double getB()
  {
    return dblB;
  }

  /**Set side length b. This method is called only by the JSF framework
   * in this sample
   * @param dblA Side length b
   */
  public void setB(double dblB)
  {
    this.dblB = dblB;
  }

  /**Get current user input for side length c
   * @return Side length c (might be default value if no input is available)
   */
  public double getC()
  {
    return dblC;
  }

  /**Set side length c. This method is called only by the JSF framework
   * in this sample
   * @param dblA Side length c
   */
  public void setC(double dblC)
  {
    this.dblC = dblC;
  }
  
  /**Get the volume which is calculated based on the
   * current side lengths. The calculation is performed 
   * in method @see calculate
   * 
   * @return Current volume
   */
  public double getVolume()
  {
    return this.dblVolume;
  }
  
  /**Get the surface which is calculated based on the
   * current side lengths. The calculation is performed 
   * in method @see calculate
   * 
   * @return Current surface
   */
  public double getSurface()
  {
    return this.dblSurface;
  }

  /**Get the history of all calculations in the current session
   * @return The full history of the current session
   */
  public History getHistory()
  {
    return this.history;
  }
  
  /**Button "calculate" is clicked: based on the user input
   * for a, b and c, calculate volume and surface and store it in the member variables.
   * Then add the side lengths to the history.
   * 
   * @return Navigation rule (here: "NULL" - this simple sample does not
   * have a navigation and returns always to the same JSP page)
   */
  public String berechnen()
  {
    System.out.println ("'calculate' was called!");
    
    //The member variables "dblA", "dblB" and "dblC" should contain
    //the user input for the three side lengths.
    
    //Calculate the values and store in member variables:
    this.dblVolume = this.dblA * this.dblB * this.dblC;
    this.dblSurface = 2 * (this.dblA * this.dblB) + 2 * (this.dblA * this.dblC) + 2 * (this.dblB * this.dblC);
    
    //Add to history
    SideLengths sideLengthCurrent = new SideLengths();
    sideLengthCurrent.setA(this.dblA);
    sideLengthCurrent.setB(this.dblB);
    sideLengthCurrent.setC(this.dblC);
    this.history.addSideLength(sideLengthCurrent );
    
    //Return value does not matter, because this simple sample has no navigation rules.
    return null;
  }
}
